==> pycite-0.1.0.tar.gz: pycite-0.1.0/README.md <==
# pycite: Python Citations Generator 


[![DOI](https://zenodo.org/badge/367264942.svg)](https://zenodo.org/badge/latestdoi/367264942)
[![PyPI version fury.io](https://badge.fury.io/py/pycite.svg)](https://pypi.python.org/pypi/pycite/)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active) 
[![Codecov](https://codecov.io/gh/Nelson-Gon/pycite/branch/master/graph/badge.svg)](https://codecov.io/gh/Nelson-Gon/pycite?branch=master)
![Test-Package](https://github.com/Nelson-Gon/pycite/workflows/Test-Package/badge.svg)
![Travis Build](https://travis-ci.com/Nelson-Gon/pycite.svg?branch=master)
[![PyPI license](https://img.shields.io/pypi/l/pycite.svg)](https://pypi.python.org/pypi/pycite/)
[![Documentation Status](https://readthedocs.org/projects/pycite/badge/?version=latest)](https://pycite.readthedocs.io/en/latest/?badge=latest)
[![Total Downloads](https://pepy.tech/badge/pycite)](https://pepy.tech/project/pycite)
[![Monthly Downloads](https://pepy.tech/badge/pycite/month)](https://pepy.tech/project/pycite)
[![Weekly Downloads](https://pepy.tech/badge/pycite/week)](https://pepy.tech/project/pycite)
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/Nelson-Gon/pycite/graphs/commit-activity)
[![GitHub last commit](https://img.shields.io/github/last-commit/Nelson-Gon/pycite.svg)](https://github.com/Nelson-Gon/pycite/commits/master)
[![GitHub issues](https://img.shields.io/github/issues/Nelson-Gon/pycite.svg)](https://GitHub.com/Nelson-Gon/pycite/issues/)
[![GitHub issues-closed](https://img.shields.io/github/issues-closed/Nelson-Gon/pycite.svg)](https://GitHub.com/Nelson-Gon/pycite/issues?q=is%3Aissue+is%3Aclosed)



`pycite` is a simple to use `python` citations generator.


**Supported Reference Styles**

- [ ] Harvard 

**Supported file formats**

`pycite` generates citations given a file of the following types:

- [ ] Text files (`.txt`)





# Installation

The simplest way to install the latest release is as follows:

```shell
pip install pycite

```

To install the development version:


Open the Terminal/CMD/Git bash/shell and enter

```shell

pip install git+https://github.com/Nelson-Gon/pycite.git

# or for the less stable dev version
pip install git+https://github.com/Nelson-Gon/pycite.git@dev

```

Otherwise:

```shell
# clone the repo
git clone git@github.com:Nelson-Gon/pycite.git
cd pycite
python3 setup.py install

```

# Usage 

First, one needs to create an object of class `PyCite`

```python
from pycite.pycite import PyCite
```

```python
my_citations = PyCite("path_to_links_file")
```

To generate citations, one simply calls the `cite` method.

```python
mycitations.cite()
```

---

**Thank you very much and Keep Building**. 

> To report any issues, suggestions or improvement, please do so 
at [issues](https://github.com/Nelson-Gon/pycite/issues). 

> “Before software can be reusable it first has to be usable.” – Ralph Johnson

==> pycite-0.1.1.tar.gz: pycite-0.1.1/README.md <==
# pycite: Python Citations Generator 


[![DOI](https://zenodo.org/badge/367264942.svg)](https://zenodo.org/badge/latestdoi/367264942)
[![PyPI version fury.io](https://badge.fury.io/py/pycite.svg)](https://pypi.python.org/pypi/pycite/)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active) 
[![Codecov](https://codecov.io/gh/Nelson-Gon/pycite/branch/dev/graph/badge.svg)](https://codecov.io/gh/Nelson-Gon/pycite?branch=dev)
![Test-Package](https://github.com/Nelson-Gon/pycite/workflows/Test-Package/badge.svg)
[![Build Status](https://www.travis-ci.com/Nelson-Gon/pycite.svg?branch=main)](https://www.travis-ci.com/Nelson-Gon/pycite)
[![PyPI license](https://img.shields.io/pypi/l/pycite.svg)](https://pypi.python.org/pypi/pycite/)
[![Documentation Status](https://readthedocs.org/projects/pycite/badge/?version=latest)](https://pycite.readthedocs.io/en/latest/?badge=latest)
[![Total Downloads](https://pepy.tech/badge/pycite)](https://pepy.tech/project/pycite)
[![Monthly Downloads](https://pepy.tech/badge/pycite/month)](https://pepy.tech/project/pycite)
[![Weekly Downloads](https://pepy.tech/badge/pycite/week)](https://pepy.tech/project/pycite)
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/Nelson-Gon/pycite/graphs/commit-activity)
[![GitHub last commit](https://img.shields.io/github/last-commit/Nelson-Gon/pycite.svg)](https://github.com/Nelson-Gon/pycite/commits/main)
[![GitHub issues](https://img.shields.io/github/issues/Nelson-Gon/pycite.svg)](https://GitHub.com/Nelson-Gon/pycite/issues/)
[![GitHub issues-closed](https://img.shields.io/github/issues-closed/Nelson-Gon/pycite.svg)](https://GitHub.com/Nelson-Gon/pycite/issues?q=is%3Aissue+is%3Aclosed)



`pycite` is a simple to use `python` citations generator.


**Supported Reference Styles**

- [x] Harvard 

**Supported Paper Sources**

- [x] NCBI

- [x] Pubmed

**Supported file formats**

`pycite` generates citations given a file of the following types:

- [x] Text files (`.txt`)





# Installation

The simplest way to install the latest release is as follows:

```shell
pip install pycite

```

To install the development version:


Open the Terminal/CMD/Git bash/shell and enter

```shell

pip install git+https://github.com/Nelson-Gon/pycite.git

# or for the less stable dev version
pip install git+https://github.com/Nelson-Gon/pycite.git@dev

```

Otherwise:

```shell
# clone the repo
git clone git@github.com:Nelson-Gon/pycite.git
cd pycite
python3 setup.py install

```

# Usage 

First, one needs to create an object of class `PyCite`

```python
from pycite.pycite import PyCite
```

```python
# Need an input-output file pair 
my_citations = PyCite(input_file="testfiles/testlinks.txt", output_file="testfiles/citations.txt")
```

To generate citations, one simply calls the `cite` method.

```python
# This will write citations in the provided output file 
my_citations.cite()
```

The above gives us (only the first line is shown here). 
See [citations.txt](https://github.com/Nelson-Gon/pycite/blob/main/testfiles/citations.txt) for the full file.
```shell

Pohorille A, Wilson MA, & Shannon G Flexible Proteins at the Origin of Life (2017) Life (Basel), 7(2)
```

# Notes

This software is provided freely. If you have any concerns, please contact the author. Specifically, the papers
used to test that the software works have been randomly chosen. In the event that you notice that any of those papers has 
been retracted, please immediately inform the author to remove that paper from the tests.

**For Science!**

To report any issues, suggestions or improvement, please do so 
at [issues](https://github.com/Nelson-Gon/pycite/issues). 

> “Before software can be reusable it first has to be usable.” – Ralph Johnson
